@@ -82,6 +82,10 @@ MutableProcInfo()
 #endif
     start_time(0UL),
     cpu_time(0ULL),
+    disk_write_bytes_current(0ULL),
+    disk_read_bytes_current(0ULL),
+    disk_write_bytes_total(0ULL),
+    disk_read_bytes_total(0ULL),
     status(0U),
     pcpu(0U),
     nice(0)
@@ -109,6 +113,10 @@ MutableProcInfo()
 
     gulong start_time;
     guint64 cpu_time;
+    guint64 disk_write_bytes_current;
+    guint64 disk_read_bytes_current;
+    guint64 disk_write_bytes_total;
+    guint64 disk_read_bytes_total;
     guint status;
     guint pcpu;
     gint nice;
@@ -164,7 +172,7 @@ public:
         std::lock_guard<std::mutex> lg(data_lock);
         return data.erase(it);
     }
-    ProcInfo* add(pid_t pid) { return &data.emplace(pid, pid).first->second; }
+    ProcInfo* add(pid_t pid) { return &data.emplace(std::piecewise_construct, std::forward_as_tuple(pid), std::forward_as_tuple(pid)).first->second; }
     void clear() { return data.clear(); }
 
     ProcInfo* find(pid_t pid);
